summaryrefslogtreecommitdiffstats
path: root/libkdepim/kregexp3.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/kregexp3.h')
-rw-r--r--libkdepim/kregexp3.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libkdepim/kregexp3.h b/libkdepim/kregexp3.h
index 64a874d3a..c58feb9d1 100644
--- a/libkdepim/kregexp3.h
+++ b/libkdepim/kregexp3.h
@@ -36,11 +36,11 @@
#include <kdepimmacros.h>
/** @short A TQRegExp (TQt3.x) with a tqreplace() method.
This class is simply there to provide a namespace for some nice
enhancements of the mighty TQRegExp (TQt3 version) regular
- expression engine, namely the method tqreplace(), which can be
+ expression engine, namely the method replace(), which can be
used to do search-and-replace like one is used to from perl or sed.
It "simply" adds the ability to define a replacement string which
@@ -105,7 +105,7 @@ public:
Equivalent to the /g switch to perl's s/// operator.
@return The modified string.
*/
- TQString tqreplace( const TQString & str,
+ TQString replace( const TQString & str,
const TQString & replacementStr,
int start=0, bool global=TRUE );
};
@@ -36,11 +36,11 @@
#include <kdepimmacros.h>
-/** @short A TQRegExp (TQt3.x) with a tqreplace() method.
+/** @short A TQRegExp (TQt3.x) with a replace() method.
This class is simply there to provide a namespace for some nice
enhancements of the mighty TQRegExp (TQt3 version) regular